.. include:: ../README.rst

Documentation contents
======================

.. toctree::
    :maxdepth: 2

    Manpage <manpage>
    cookbook

Although :program:`tpl` is primarily developed as a CLI program there is some
documentation of it's internals in the :doc:`Python API <api>` section.


.. toctree::
    :maxdepth: 2

    api
    license
    changelog

